@@ -24,9 +24,11 @@ namespace N
 		int d;
 		int getStats();
 		double getPvalue();
-		std::vector<std::string> getInteraction();
+		std::string getInteraction();
+		std::map<std::string, int, std::greater<std::string>> getGrids();
 		std::vector<std::vector<std::string>> getSymmInteraction();
 		std::vector<int> getSymmStats();
+		std::vector<std::vector<int>> getAllColor();
 		std::vector<std::string> getBinary();
 		void Beast(std::size_t m, std::size_t B, double lambda, bool test_uniformity, bool test_independence, std::vector<std::vector<std::size_t>>& independence_index);
 		double getBeastStat();
@@ -53,8 +55,12 @@ namespace N
 		std::vector<std::vector<int>> inter_mat;
 		std::vector<std::vector<std::size_t>> allidx;
 		std::vector<std::size_t> thread;
-		// std::map<std::vector<int>, int> countInteraction;
+		// new: ecdf & count cells
+		std::vector<std::vector<int>> cell;
+		std::map<std::vector<int>, int> countGrid;
 		std::unordered_map<std::string, int> countInteraction;
+		std::vector<std::vector<int>> pat;
+		bool ifIter = 0;
 		// std::vector<int> freqInter;
 		// std::vector<std::vector<int>> BeastInter;
 		std::string freqInter;
@@ -62,7 +68,7 @@ namespace N
 		double BeastStat = 0;
 		double pvalue = 0;
 		// std::vector<std::vector<double>> imp(Rcpp::NumericMatrix& X);
-		std::vector<std::string> interaction_str;
+		std::string interaction_str;
 		std::vector<std::vector<int>> interactions();
 		std::vector<std::vector<int>> interaction_mat();
 		std::vector<std::string> interaction_index();
@@ -72,9 +78,19 @@ namespace N
 		std::map<std::vector<int>, int> groupC(std::vector<std::vector<int>>& c);
 		int locate(int c, long long b);
 		std::vector<std::vector<std::vector<int>>> CBIDs(std::map<std::vector<int>, int>& count);
-		std::vector<std::vector<std::size_t>> allComb();
+		//new func: all 1/-1 for n points
+		std::vector<std::vector<int>> allColor(std::vector<std::vector<int>>& Cij);
+		std::vector<std::vector<std::size_t>> allComb(size_t p, int dep);
 		bool isIndex(std::vector<std::size_t>& idx);
 		std::vector<int> symmstats(std::vector<int>& countValues, std::vector<std::vector<std::vector<int>>>& matrix, size_t sampleSize);
+		//new version for symmstats: iterBET
+		std::map<std::vector<int>, int> allPosition(int dep);
+		std::vector<std::vector<int>> getPattern();
+		std::string convert(size_t idx);
+		std::vector<std::string> idxFilter();
+		std::vector<int> iterBET(std::map<std::vector<int>, int>& posi);
+
+
 		std::vector<std::size_t> unreplaceShuffle(std::size_t size, std::size_t max_size);
 		std::vector<double> subsample(size_t m, size_t B);
 		std::vector<double> softthreshold(std::vector<double>& S, double lambda);
